# Workbench Blogs
!!! tip inline end "Just Getting Started?"
    The Workbench Code Blogs is a great way to see what's possible with Workbench. Also if you're ready to jump in the [API Classes](../api_classes/overview.md) will give you details on the Workbench ML Pipeline Classes.
    
Workbench blogs are intended to show the actual steps/code around each blog topic. We also take a candid look at what worked well and where the current toolkit might need some feature improvements.

## Latest Blogs

- **[Molecular Descriptors Issues for AqSol Data](descriptor_drilldown.md):** In this Blog we'll look at the popular AqSol compound solubility dataset, compute Molecular Descriptors (RDKit and Mordred) and take a deep dive on why NaNs, INFs, and parse errors are generated on about 9% of the compounds.

- **[AqSol Residual Analysis](residual_analysis.md):** In this Blog we'll look at the popular AqSol compound solubility dataset and walk backward through the ML pipeline by starting with model residuals and backtracking to the features and input data.

## Corner Cases

These blogs are odd corner cases that we stumbled into and discovered some interesting aspect of Cloud Platforms or ML Pipelines. 

- **[AWS Credentials Refresh Lock](aws_credentials_lock.md)** We discover that the AWS botocore library has a threading lock when refreshing credentials.


## Questions?
<img align="right" src="../../images/scp.png" width="180">

The SuperCowPowers team is happy to answer any questions you may have about AWS and Workbench. Please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 
